import { AxiosResponse } from 'axios'
import {
    PageInputAdKuaKePageInput,
    ResultOutputPageOutputAdKuaKePageOutput,  
    UpdateKuaKeStatusInput
} from './data-contracts'
import { ContentType, HttpClient, RequestParams } from './http-client'

export class KuaKeApi<SecurityDataType = unknown> extends HttpClient<SecurityDataType>{
    /**
   * No description
   *
   * @tags ad-kua-ke
   * @name GetPage
   * @summary 查询分页
   * @request POST:/api/admin/ad-kua-ke/get-page
   * @secure
   */
    getPage = (data: PageInputAdKuaKePageInput, params: RequestParams = {}) =>
        this.request<ResultOutputPageOutputAdKuaKePageOutput, any>({
            path: `/api/admin/ad-kua-ke/get-page`,
            method: 'Post',
            body: data,
            secure: true,
            type: ContentType.Json,
            format: 'json',
            ...params,
        })     
    /**
     * No description
     *
     * @tags ad-kua-ke
     * @name update-status
     * @summary 修改状态
     * @request PUT:/api/admin/notice/update
     * @secure
     */
    updateStatus = (data: UpdateKuaKeStatusInput, params: RequestParams = {}) =>
        this.request<AxiosResponse, any>({
            path: `/api/admin/ad-kua-ke/update-status`,
            method: 'PUT',
            body: data,
            secure: true,
            type: ContentType.Json,
            ...params,
        })
    /**
   * No description
   *
   * @tags ad-kua-ke
   * @name GetPage
   * @summary 导出excel
   * @request POST:/api/admin/ad-kua-ke/get-excel
   * @secure
   */
    getExcel = (data: PageInputAdKuaKePageInput, params: RequestParams = {}) =>
        this.request<AxiosResponse, any>({
            path: `/api/admin/ad-kua-ke/get-excel`,
            method: 'Post',
            body: data,
            secure: true,
            type: ContentType.Json,
            format: 'json',
            ...params,
        })
}